@@ -448,7 +448,7 @@ fn get_record_not_found() {
     let target_key = record::Key::from(random_multihash());
     let qid = swarms[0]
         .behaviour_mut()
-        .get_record(&target_key, Quorum::One);
+        .get_record(target_key.clone(), Quorum::One);
 
     block_on(poll_fn(move |ctx| {
         for swarm in &mut swarms {
@@ -761,7 +761,7 @@ fn get_record() {
     swarms[2].behaviour_mut().store.put(record.clone()).unwrap();
     let qid = swarms[0]
         .behaviour_mut()
-        .get_record(&record.key, Quorum::One);
+        .get_record(record.key.clone(), Quorum::One);
 
     block_on(poll_fn(move |ctx| {
         for swarm in &mut swarms {
@@ -817,7 +817,9 @@ fn get_record_many() {
     }
 
     let quorum = Quorum::N(NonZeroUsize::new(num_results).unwrap());
-    let qid = swarms[0].behaviour_mut().get_record(&record.key, quorum);
+    let qid = swarms[0]
+        .behaviour_mut()
+        .get_record(record.key.clone(), quorum);
 
     block_on(poll_fn(move |ctx| {
         for swarm in &mut swarms {
@@ -1116,7 +1118,7 @@ fn disjoint_query_does_not_finish_before_all_paths_did() {
     let (mut alice, mut bob, mut trudy) = (alice.1, bob.1, trudy.1);
 
     // Have `alice` query the Dht for `key` with a quorum of 1.
-    alice.behaviour_mut().get_record(&key, Quorum::One);
+    alice.behaviour_mut().get_record(key, Quorum::One);
 
     // The default peer timeout is 10 seconds. Choosing 1 seconds here should
     // give enough head room to prevent connections to `bob` to time out.
@@ -1291,8 +1293,7 @@ fn network_behaviour_inject_address_change() {
     };
 
     // Mimick a connection being established.
-    kademlia.inject_connection_established(&remote_peer_id, &connection_id, &endpoint, None);
-    kademlia.inject_connected(&remote_peer_id);
+    kademlia.inject_connection_established(&remote_peer_id, &connection_id, &endpoint, None, 0);
 
     // At this point the remote is not yet known to support the
     // configured protocol name, so the peer is not yet in the
